# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepVisual module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepvisual.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepVisual
else:
    import _RWStepVisual

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepVisual.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepVisual.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepVisual.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepVisual.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepVisual.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepVisual.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepVisual.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepVisual.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepVisual.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepVisual.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepVisual.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepVisual.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepVisual.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepVisual.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepVisual.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepVisual.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepVisual.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepVisual:
_RWStepVisual.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepVisual.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepVisual
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepRepr
import OCC.Core.StepBasic
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepVisual_RWAnnotationCurveOccurrence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrence_swiginit(self, _RWStepVisual.new_RWStepVisual_RWAnnotationCurveOccurrence(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_AnnotationCurveOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrence_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_AnnotationCurveOccurrence
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrence_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_AnnotationCurveOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrence_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWAnnotationCurveOccurrence

# Register RWStepVisual_RWAnnotationCurveOccurrence in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrence_swigregister(RWStepVisual_RWAnnotationCurveOccurrence)

class RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem_swiginit(self, _RWStepVisual.new_RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_AnnotationCurveOccurrenceAndGeomReprItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_AnnotationCurveOccurrenceAndGeomReprItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_AnnotationCurveOccurrenceAndGeomReprItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem

# Register RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem_swigregister(RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem)

class RWStepVisual_RWAnnotationFillArea(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWAnnotationFillArea_swiginit(self, _RWStepVisual.new_RWStepVisual_RWAnnotationFillArea(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_AnnotationFillArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationFillArea_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_AnnotationFillArea
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationFillArea_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_AnnotationFillArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationFillArea_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWAnnotationFillArea

# Register RWStepVisual_RWAnnotationFillArea in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWAnnotationFillArea_swigregister(RWStepVisual_RWAnnotationFillArea)

class RWStepVisual_RWAnnotationFillAreaOccurrence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWAnnotationFillAreaOccurrence_swiginit(self, _RWStepVisual.new_RWStepVisual_RWAnnotationFillAreaOccurrence(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_AnnotationFillAreaOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationFillAreaOccurrence_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_AnnotationFillAreaOccurrence
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationFillAreaOccurrence_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_AnnotationFillAreaOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationFillAreaOccurrence_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWAnnotationFillAreaOccurrence

# Register RWStepVisual_RWAnnotationFillAreaOccurrence in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWAnnotationFillAreaOccurrence_swigregister(RWStepVisual_RWAnnotationFillAreaOccurrence)

class RWStepVisual_RWAnnotationOccurrence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWAnnotationOccurrence_swiginit(self, _RWStepVisual.new_RWStepVisual_RWAnnotationOccurrence(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_AnnotationOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationOccurrence_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_AnnotationOccurrence
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationOccurrence_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_AnnotationOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationOccurrence_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWAnnotationOccurrence

# Register RWStepVisual_RWAnnotationOccurrence in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWAnnotationOccurrence_swigregister(RWStepVisual_RWAnnotationOccurrence)

class RWStepVisual_RWAnnotationPlane(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWAnnotationPlane_swiginit(self, _RWStepVisual.new_RWStepVisual_RWAnnotationPlane(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_AnnotationPlane

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationPlane_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_AnnotationPlane
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationPlane_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_AnnotationPlane

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAnnotationPlane_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWAnnotationPlane

# Register RWStepVisual_RWAnnotationPlane in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWAnnotationPlane_swigregister(RWStepVisual_RWAnnotationPlane)

class RWStepVisual_RWAreaInSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWAreaInSet_swiginit(self, _RWStepVisual.new_RWStepVisual_RWAreaInSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_AreaInSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAreaInSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_AreaInSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAreaInSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_AreaInSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWAreaInSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWAreaInSet

# Register RWStepVisual_RWAreaInSet in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWAreaInSet_swigregister(RWStepVisual_RWAreaInSet)

class RWStepVisual_RWBackgroundColour(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWBackgroundColour_swiginit(self, _RWStepVisual.new_RWStepVisual_RWBackgroundColour(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_BackgroundColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWBackgroundColour_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_BackgroundColour
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWBackgroundColour_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_BackgroundColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWBackgroundColour_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWBackgroundColour

# Register RWStepVisual_RWBackgroundColour in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWBackgroundColour_swigregister(RWStepVisual_RWBackgroundColour)

class RWStepVisual_RWCameraImage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraImage_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraImage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraImage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraImage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CameraImage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraImage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraImage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraImage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraImage

# Register RWStepVisual_RWCameraImage in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraImage_swigregister(RWStepVisual_RWCameraImage)

class RWStepVisual_RWCameraModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraModel_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraModel

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModel_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraModel

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraModel

# Register RWStepVisual_RWCameraModel in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraModel_swigregister(RWStepVisual_RWCameraModel)

class RWStepVisual_RWCameraModelD2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraModelD2_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraModelD2(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraModelD2

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD2_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CameraModelD2
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD2_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraModelD2

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD2_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraModelD2

# Register RWStepVisual_RWCameraModelD2 in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraModelD2_swigregister(RWStepVisual_RWCameraModelD2)

class RWStepVisual_RWCameraModelD3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraModelD3_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraModelD3(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraModelD3

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CameraModelD3
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraModelD3

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraModelD3

# Register RWStepVisual_RWCameraModelD3 in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraModelD3_swigregister(RWStepVisual_RWCameraModelD3)

class RWStepVisual_RWCameraModelD3MultiClipping(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClipping_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraModelD3MultiClipping(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraModelD3MultiClipping

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClipping_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CameraModelD3MultiClipping
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClipping_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraModelD3MultiClipping

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClipping_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraModelD3MultiClipping

# Register RWStepVisual_RWCameraModelD3MultiClipping in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraModelD3MultiClipping_swigregister(RWStepVisual_RWCameraModelD3MultiClipping)

class RWStepVisual_RWCameraModelD3MultiClippingIntersection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingIntersection_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraModelD3MultiClippingIntersection(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraModelD3MultiClippingIntersection

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingIntersection_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CameraModelD3MultiClippingIntersection
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingIntersection_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraModelD3MultiClippingIntersection

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingIntersection_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraModelD3MultiClippingIntersection

# Register RWStepVisual_RWCameraModelD3MultiClippingIntersection in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingIntersection_swigregister(RWStepVisual_RWCameraModelD3MultiClippingIntersection)

class RWStepVisual_RWCameraModelD3MultiClippingUnion(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingUnion_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraModelD3MultiClippingUnion(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraModelD3MultiClippingUnion

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingUnion_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CameraModelD3MultiClippingUnion
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingUnion_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraModelD3MultiClippingUnion

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingUnion_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraModelD3MultiClippingUnion

# Register RWStepVisual_RWCameraModelD3MultiClippingUnion in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraModelD3MultiClippingUnion_swigregister(RWStepVisual_RWCameraModelD3MultiClippingUnion)

class RWStepVisual_RWCameraUsage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCameraUsage_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCameraUsage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CameraUsage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraUsage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CameraUsage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraUsage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CameraUsage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCameraUsage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCameraUsage

# Register RWStepVisual_RWCameraUsage in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCameraUsage_swigregister(RWStepVisual_RWCameraUsage)

class RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel

# Register RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel_swigregister(RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel)

class RWStepVisual_RWColour(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWColour_swiginit(self, _RWStepVisual.new_RWStepVisual_RWColour(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_Colour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWColour_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_Colour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWColour_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWColour

# Register RWStepVisual_RWColour in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWColour_swigregister(RWStepVisual_RWColour)

class RWStepVisual_RWColourRgb(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWColourRgb_swiginit(self, _RWStepVisual.new_RWStepVisual_RWColourRgb(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_ColourRgb

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWColourRgb_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_ColourRgb

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWColourRgb_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWColourRgb

# Register RWStepVisual_RWColourRgb in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWColourRgb_swigregister(RWStepVisual_RWColourRgb)

class RWStepVisual_RWColourSpecification(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWColourSpecification_swiginit(self, _RWStepVisual.new_RWStepVisual_RWColourSpecification(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_ColourSpecification

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWColourSpecification_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_ColourSpecification

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWColourSpecification_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWColourSpecification

# Register RWStepVisual_RWColourSpecification in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWColourSpecification_swigregister(RWStepVisual_RWColourSpecification)

class RWStepVisual_RWCompositeText(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCompositeText_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCompositeText(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CompositeText

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCompositeText_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CompositeText
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCompositeText_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CompositeText

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCompositeText_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCompositeText

# Register RWStepVisual_RWCompositeText in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCompositeText_swigregister(RWStepVisual_RWCompositeText)

class RWStepVisual_RWCompositeTextWithExtent(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCompositeTextWithExtent_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCompositeTextWithExtent(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CompositeTextWithExtent

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCompositeTextWithExtent_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CompositeTextWithExtent
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCompositeTextWithExtent_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CompositeTextWithExtent

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCompositeTextWithExtent_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCompositeTextWithExtent

# Register RWStepVisual_RWCompositeTextWithExtent in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCompositeTextWithExtent_swigregister(RWStepVisual_RWCompositeTextWithExtent)

class RWStepVisual_RWContextDependentInvisibility(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWContextDependentInvisibility_swiginit(self, _RWStepVisual.new_RWStepVisual_RWContextDependentInvisibility(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_ContextDependentInvisibility

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWContextDependentInvisibility_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_ContextDependentInvisibility
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWContextDependentInvisibility_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_ContextDependentInvisibility

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWContextDependentInvisibility_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWContextDependentInvisibility

# Register RWStepVisual_RWContextDependentInvisibility in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWContextDependentInvisibility_swigregister(RWStepVisual_RWContextDependentInvisibility)

class RWStepVisual_RWContextDependentOverRidingStyledItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWContextDependentOverRidingStyledItem_swiginit(self, _RWStepVisual.new_RWStepVisual_RWContextDependentOverRidingStyledItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_ContextDependentOverRidingStyledItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWContextDependentOverRidingStyledItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_ContextDependentOverRidingStyledItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWContextDependentOverRidingStyledItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_ContextDependentOverRidingStyledItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWContextDependentOverRidingStyledItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWContextDependentOverRidingStyledItem

# Register RWStepVisual_RWContextDependentOverRidingStyledItem in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWContextDependentOverRidingStyledItem_swigregister(RWStepVisual_RWContextDependentOverRidingStyledItem)

class RWStepVisual_RWCoordinatesList(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCoordinatesList_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCoordinatesList(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CoordinatesList

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCoordinatesList_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CoordinatesList

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCoordinatesList_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCoordinatesList

# Register RWStepVisual_RWCoordinatesList in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCoordinatesList_swigregister(RWStepVisual_RWCoordinatesList)

class RWStepVisual_RWCurveStyle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCurveStyle_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCurveStyle(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyle_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CurveStyle
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyle_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CurveStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyle_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCurveStyle

# Register RWStepVisual_RWCurveStyle in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCurveStyle_swigregister(RWStepVisual_RWCurveStyle)

class RWStepVisual_RWCurveStyleFont(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCurveStyleFont_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCurveStyleFont(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CurveStyleFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyleFont_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_CurveStyleFont
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyleFont_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CurveStyleFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyleFont_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCurveStyleFont

# Register RWStepVisual_RWCurveStyleFont in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCurveStyleFont_swigregister(RWStepVisual_RWCurveStyleFont)

class RWStepVisual_RWCurveStyleFontPattern(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWCurveStyleFontPattern_swiginit(self, _RWStepVisual.new_RWStepVisual_RWCurveStyleFontPattern(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_CurveStyleFontPattern

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyleFontPattern_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_CurveStyleFontPattern

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWCurveStyleFontPattern_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWCurveStyleFontPattern

# Register RWStepVisual_RWCurveStyleFontPattern in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWCurveStyleFontPattern_swigregister(RWStepVisual_RWCurveStyleFontPattern)

class RWStepVisual_RWDraughtingCallout(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWDraughtingCallout_swiginit(self, _RWStepVisual.new_RWStepVisual_RWDraughtingCallout(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_DraughtingCallout

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingCallout_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_DraughtingCallout
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingCallout_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_DraughtingCallout

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingCallout_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWDraughtingCallout

# Register RWStepVisual_RWDraughtingCallout in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWDraughtingCallout_swigregister(RWStepVisual_RWDraughtingCallout)

class RWStepVisual_RWDraughtingModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWDraughtingModel_swiginit(self, _RWStepVisual.new_RWStepVisual_RWDraughtingModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads draughtingmodel.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_DraughtingModel

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingModel_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepVisual_DraughtingModel
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingModel_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes draughtingmodel.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_DraughtingModel

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWDraughtingModel

# Register RWStepVisual_RWDraughtingModel in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWDraughtingModel_swigregister(RWStepVisual_RWDraughtingModel)

class RWStepVisual_RWDraughtingPreDefinedColour(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWDraughtingPreDefinedColour_swiginit(self, _RWStepVisual.new_RWStepVisual_RWDraughtingPreDefinedColour(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_DraughtingPreDefinedColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingPreDefinedColour_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_DraughtingPreDefinedColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingPreDefinedColour_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWDraughtingPreDefinedColour

# Register RWStepVisual_RWDraughtingPreDefinedColour in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWDraughtingPreDefinedColour_swigregister(RWStepVisual_RWDraughtingPreDefinedColour)

class RWStepVisual_RWDraughtingPreDefinedCurveFont(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWDraughtingPreDefinedCurveFont_swiginit(self, _RWStepVisual.new_RWStepVisual_RWDraughtingPreDefinedCurveFont(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_DraughtingPreDefinedCurveFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingPreDefinedCurveFont_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_DraughtingPreDefinedCurveFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWDraughtingPreDefinedCurveFont_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWDraughtingPreDefinedCurveFont

# Register RWStepVisual_RWDraughtingPreDefinedCurveFont in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWDraughtingPreDefinedCurveFont_swigregister(RWStepVisual_RWDraughtingPreDefinedCurveFont)

class RWStepVisual_RWExternallyDefinedCurveFont(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWExternallyDefinedCurveFont_swiginit(self, _RWStepVisual.new_RWStepVisual_RWExternallyDefinedCurveFont(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externallydefinedcurvefont.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_ExternallyDefinedCurveFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWExternallyDefinedCurveFont_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepVisual_ExternallyDefinedCurveFont
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWExternallyDefinedCurveFont_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externallydefinedcurvefont.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_ExternallyDefinedCurveFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWExternallyDefinedCurveFont_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWExternallyDefinedCurveFont

# Register RWStepVisual_RWExternallyDefinedCurveFont in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWExternallyDefinedCurveFont_swigregister(RWStepVisual_RWExternallyDefinedCurveFont)

class RWStepVisual_RWFillAreaStyle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWFillAreaStyle_swiginit(self, _RWStepVisual.new_RWStepVisual_RWFillAreaStyle(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_FillAreaStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWFillAreaStyle_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_FillAreaStyle
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWFillAreaStyle_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_FillAreaStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWFillAreaStyle_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWFillAreaStyle

# Register RWStepVisual_RWFillAreaStyle in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWFillAreaStyle_swigregister(RWStepVisual_RWFillAreaStyle)

class RWStepVisual_RWFillAreaStyleColour(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWFillAreaStyleColour_swiginit(self, _RWStepVisual.new_RWStepVisual_RWFillAreaStyleColour(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_FillAreaStyleColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWFillAreaStyleColour_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_FillAreaStyleColour
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWFillAreaStyleColour_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_FillAreaStyleColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWFillAreaStyleColour_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWFillAreaStyleColour

# Register RWStepVisual_RWFillAreaStyleColour in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWFillAreaStyleColour_swigregister(RWStepVisual_RWFillAreaStyleColour)

class RWStepVisual_RWInvisibility(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWInvisibility_swiginit(self, _RWStepVisual.new_RWStepVisual_RWInvisibility(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_Invisibility

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWInvisibility_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_Invisibility
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWInvisibility_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_Invisibility

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWInvisibility_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWInvisibility

# Register RWStepVisual_RWInvisibility in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWInvisibility_swigregister(RWStepVisual_RWInvisibility)

class RWStepVisual_RWMechanicalDesignGeometricPresentationArea(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationArea_swiginit(self, _RWStepVisual.new_RWStepVisual_RWMechanicalDesignGeometricPresentationArea(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_MechanicalDesignGeometricPresentationArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationArea_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_MechanicalDesignGeometricPresentationArea
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationArea_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_MechanicalDesignGeometricPresentationArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationArea_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWMechanicalDesignGeometricPresentationArea

# Register RWStepVisual_RWMechanicalDesignGeometricPresentationArea in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationArea_swigregister(RWStepVisual_RWMechanicalDesignGeometricPresentationArea)

class RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation_swiginit(self, _RWStepVisual.new_RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_MechanicalDesignGeometricPresentationRepresentation

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_MechanicalDesignGeometricPresentationRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_MechanicalDesignGeometricPresentationRepresentation

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation

# Register RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation_swigregister(RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation)

class RWStepVisual_RWOverRidingStyledItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWOverRidingStyledItem_swiginit(self, _RWStepVisual.new_RWStepVisual_RWOverRidingStyledItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_OverRidingStyledItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWOverRidingStyledItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_OverRidingStyledItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWOverRidingStyledItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_OverRidingStyledItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWOverRidingStyledItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWOverRidingStyledItem

# Register RWStepVisual_RWOverRidingStyledItem in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWOverRidingStyledItem_swigregister(RWStepVisual_RWOverRidingStyledItem)

class RWStepVisual_RWPlanarBox(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPlanarBox_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPlanarBox(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PlanarBox

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPlanarBox_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PlanarBox
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPlanarBox_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PlanarBox

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPlanarBox_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPlanarBox

# Register RWStepVisual_RWPlanarBox in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPlanarBox_swigregister(RWStepVisual_RWPlanarBox)

class RWStepVisual_RWPlanarExtent(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPlanarExtent_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPlanarExtent(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PlanarExtent

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPlanarExtent_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PlanarExtent

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPlanarExtent_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPlanarExtent

# Register RWStepVisual_RWPlanarExtent in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPlanarExtent_swigregister(RWStepVisual_RWPlanarExtent)

class RWStepVisual_RWPointStyle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPointStyle_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPointStyle(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PointStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPointStyle_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PointStyle
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPointStyle_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PointStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPointStyle_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPointStyle

# Register RWStepVisual_RWPointStyle in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPointStyle_swigregister(RWStepVisual_RWPointStyle)

class RWStepVisual_RWPreDefinedColour(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPreDefinedColour_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPreDefinedColour(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PreDefinedColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPreDefinedColour_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PreDefinedColour

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPreDefinedColour_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPreDefinedColour

# Register RWStepVisual_RWPreDefinedColour in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPreDefinedColour_swigregister(RWStepVisual_RWPreDefinedColour)

class RWStepVisual_RWPreDefinedCurveFont(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPreDefinedCurveFont_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPreDefinedCurveFont(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PreDefinedCurveFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPreDefinedCurveFont_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PreDefinedCurveFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPreDefinedCurveFont_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPreDefinedCurveFont

# Register RWStepVisual_RWPreDefinedCurveFont in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPreDefinedCurveFont_swigregister(RWStepVisual_RWPreDefinedCurveFont)

class RWStepVisual_RWPreDefinedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPreDefinedItem_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPreDefinedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PreDefinedItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPreDefinedItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PreDefinedItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPreDefinedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPreDefinedItem

# Register RWStepVisual_RWPreDefinedItem in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPreDefinedItem_swigregister(RWStepVisual_RWPreDefinedItem)

class RWStepVisual_RWPresentationArea(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationArea_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationArea(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationArea_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationArea
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationArea_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationArea_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationArea

# Register RWStepVisual_RWPresentationArea in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationArea_swigregister(RWStepVisual_RWPresentationArea)

class RWStepVisual_RWPresentationLayerAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationLayerAssignment_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationLayerAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationLayerAssignment

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationLayerAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationLayerAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationLayerAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationLayerAssignment

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationLayerAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationLayerAssignment

# Register RWStepVisual_RWPresentationLayerAssignment in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationLayerAssignment_swigregister(RWStepVisual_RWPresentationLayerAssignment)

class RWStepVisual_RWPresentationLayerUsage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationLayerUsage_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationLayerUsage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationLayerUsage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationLayerUsage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationLayerUsage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationLayerUsage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationLayerUsage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationLayerUsage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationLayerUsage

# Register RWStepVisual_RWPresentationLayerUsage in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationLayerUsage_swigregister(RWStepVisual_RWPresentationLayerUsage)

class RWStepVisual_RWPresentationRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationRepresentation_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationRepresentation

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationRepresentation

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationRepresentation

# Register RWStepVisual_RWPresentationRepresentation in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationRepresentation_swigregister(RWStepVisual_RWPresentationRepresentation)

class RWStepVisual_RWPresentationSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationSet_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationSet_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationSet

# Register RWStepVisual_RWPresentationSet in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationSet_swigregister(RWStepVisual_RWPresentationSet)

class RWStepVisual_RWPresentationSize(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationSize_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationSize(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationSize

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationSize_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationSize
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationSize_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationSize

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationSize_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationSize

# Register RWStepVisual_RWPresentationSize in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationSize_swigregister(RWStepVisual_RWPresentationSize)

class RWStepVisual_RWPresentationStyleAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationStyleAssignment_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationStyleAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationStyleAssignment

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationStyleAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationStyleAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationStyleAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationStyleAssignment

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationStyleAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationStyleAssignment

# Register RWStepVisual_RWPresentationStyleAssignment in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationStyleAssignment_swigregister(RWStepVisual_RWPresentationStyleAssignment)

class RWStepVisual_RWPresentationStyleByContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationStyleByContext_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationStyleByContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationStyleByContext

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationStyleByContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationStyleByContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationStyleByContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationStyleByContext

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationStyleByContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationStyleByContext

# Register RWStepVisual_RWPresentationStyleByContext in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationStyleByContext_swigregister(RWStepVisual_RWPresentationStyleByContext)

class RWStepVisual_RWPresentationView(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentationView_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentationView(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentationView

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationView_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentationView
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationView_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentationView

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentationView_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentationView

# Register RWStepVisual_RWPresentationView in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentationView_swigregister(RWStepVisual_RWPresentationView)

class RWStepVisual_RWPresentedItemRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWPresentedItemRepresentation_swiginit(self, _RWStepVisual.new_RWStepVisual_RWPresentedItemRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_PresentedItemRepresentation

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentedItemRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_PresentedItemRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentedItemRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_PresentedItemRepresentation

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWPresentedItemRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWPresentedItemRepresentation

# Register RWStepVisual_RWPresentedItemRepresentation in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWPresentedItemRepresentation_swigregister(RWStepVisual_RWPresentedItemRepresentation)

class RWStepVisual_RWStyledItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWStyledItem_swiginit(self, _RWStepVisual.new_RWStepVisual_RWStyledItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_StyledItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWStyledItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_StyledItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWStyledItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_StyledItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWStyledItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWStyledItem

# Register RWStepVisual_RWStyledItem in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWStyledItem_swigregister(RWStepVisual_RWStyledItem)

class RWStepVisual_RWSurfaceSideStyle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceSideStyle_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceSideStyle(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceSideStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceSideStyle_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceSideStyle
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceSideStyle_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceSideStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceSideStyle_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceSideStyle

# Register RWStepVisual_RWSurfaceSideStyle in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceSideStyle_swigregister(RWStepVisual_RWSurfaceSideStyle)

class RWStepVisual_RWSurfaceStyleBoundary(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleBoundary_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleBoundary(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleBoundary

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleBoundary_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleBoundary
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleBoundary_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleBoundary

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleBoundary_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleBoundary

# Register RWStepVisual_RWSurfaceStyleBoundary in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleBoundary_swigregister(RWStepVisual_RWSurfaceStyleBoundary)

class RWStepVisual_RWSurfaceStyleControlGrid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleControlGrid_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleControlGrid(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleControlGrid

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleControlGrid_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleControlGrid
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleControlGrid_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleControlGrid

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleControlGrid_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleControlGrid

# Register RWStepVisual_RWSurfaceStyleControlGrid in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleControlGrid_swigregister(RWStepVisual_RWSurfaceStyleControlGrid)

class RWStepVisual_RWSurfaceStyleFillArea(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleFillArea_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleFillArea(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleFillArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleFillArea_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleFillArea
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleFillArea_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleFillArea

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleFillArea_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleFillArea

# Register RWStepVisual_RWSurfaceStyleFillArea in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleFillArea_swigregister(RWStepVisual_RWSurfaceStyleFillArea)

class RWStepVisual_RWSurfaceStyleParameterLine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleParameterLine_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleParameterLine(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleParameterLine

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleParameterLine_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleParameterLine
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleParameterLine_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleParameterLine

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleParameterLine_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleParameterLine

# Register RWStepVisual_RWSurfaceStyleParameterLine in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleParameterLine_swigregister(RWStepVisual_RWSurfaceStyleParameterLine)

class RWStepVisual_RWSurfaceStyleReflectanceAmbient(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleReflectanceAmbient_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleReflectanceAmbient(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleReflectanceAmbient

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleReflectanceAmbient_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleReflectanceAmbient
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleReflectanceAmbient_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleReflectanceAmbient

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleReflectanceAmbient_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleReflectanceAmbient

# Register RWStepVisual_RWSurfaceStyleReflectanceAmbient in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleReflectanceAmbient_swigregister(RWStepVisual_RWSurfaceStyleReflectanceAmbient)

class RWStepVisual_RWSurfaceStyleRendering(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleRendering_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleRendering(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleRendering

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleRendering_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleRendering
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleRendering_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleRendering

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleRendering_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleRendering

# Register RWStepVisual_RWSurfaceStyleRendering in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleRendering_swigregister(RWStepVisual_RWSurfaceStyleRendering)

class RWStepVisual_RWSurfaceStyleRenderingWithProperties(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleRenderingWithProperties_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleRenderingWithProperties(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleRenderingWithProperties

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleRenderingWithProperties_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleRenderingWithProperties
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleRenderingWithProperties_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleRenderingWithProperties

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleRenderingWithProperties_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleRenderingWithProperties

# Register RWStepVisual_RWSurfaceStyleRenderingWithProperties in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleRenderingWithProperties_swigregister(RWStepVisual_RWSurfaceStyleRenderingWithProperties)

class RWStepVisual_RWSurfaceStyleSegmentationCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleSegmentationCurve_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleSegmentationCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleSegmentationCurve

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleSegmentationCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleSegmentationCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleSegmentationCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleSegmentationCurve

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleSegmentationCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleSegmentationCurve

# Register RWStepVisual_RWSurfaceStyleSegmentationCurve in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleSegmentationCurve_swigregister(RWStepVisual_RWSurfaceStyleSegmentationCurve)

class RWStepVisual_RWSurfaceStyleSilhouette(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleSilhouette_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleSilhouette(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleSilhouette

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleSilhouette_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleSilhouette
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleSilhouette_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleSilhouette

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleSilhouette_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleSilhouette

# Register RWStepVisual_RWSurfaceStyleSilhouette in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleSilhouette_swigregister(RWStepVisual_RWSurfaceStyleSilhouette)

class RWStepVisual_RWSurfaceStyleTransparent(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleTransparent_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleTransparent(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleTransparent

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleTransparent_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleTransparent
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleTransparent_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleTransparent

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleTransparent_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleTransparent

# Register RWStepVisual_RWSurfaceStyleTransparent in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleTransparent_swigregister(RWStepVisual_RWSurfaceStyleTransparent)

class RWStepVisual_RWSurfaceStyleUsage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWSurfaceStyleUsage_swiginit(self, _RWStepVisual.new_RWStepVisual_RWSurfaceStyleUsage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_SurfaceStyleUsage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleUsage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_SurfaceStyleUsage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleUsage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_SurfaceStyleUsage

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWSurfaceStyleUsage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWSurfaceStyleUsage

# Register RWStepVisual_RWSurfaceStyleUsage in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWSurfaceStyleUsage_swigregister(RWStepVisual_RWSurfaceStyleUsage)

class RWStepVisual_RWTemplate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTemplate_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTemplate(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_Template

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTemplate_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_Template
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTemplate_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_Template

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTemplate_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTemplate

# Register RWStepVisual_RWTemplate in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTemplate_swigregister(RWStepVisual_RWTemplate)

class RWStepVisual_RWTemplateInstance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTemplateInstance_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTemplateInstance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TemplateInstance

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTemplateInstance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TemplateInstance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTemplateInstance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TemplateInstance

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTemplateInstance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTemplateInstance

# Register RWStepVisual_RWTemplateInstance in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTemplateInstance_swigregister(RWStepVisual_RWTemplateInstance)

class RWStepVisual_RWTessellatedAnnotationOccurrence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTessellatedAnnotationOccurrence_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTessellatedAnnotationOccurrence(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TessellatedAnnotationOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedAnnotationOccurrence_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TessellatedAnnotationOccurrence
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedAnnotationOccurrence_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TessellatedAnnotationOccurrence

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedAnnotationOccurrence_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTessellatedAnnotationOccurrence

# Register RWStepVisual_RWTessellatedAnnotationOccurrence in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTessellatedAnnotationOccurrence_swigregister(RWStepVisual_RWTessellatedAnnotationOccurrence)

class RWStepVisual_RWTessellatedCurveSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTessellatedCurveSet_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTessellatedCurveSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TessellatedCurveSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedCurveSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TessellatedCurveSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedCurveSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TessellatedCurveSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedCurveSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTessellatedCurveSet

# Register RWStepVisual_RWTessellatedCurveSet in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTessellatedCurveSet_swigregister(RWStepVisual_RWTessellatedCurveSet)

class RWStepVisual_RWTessellatedGeometricSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTessellatedGeometricSet_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTessellatedGeometricSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TessellatedGeometricSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedGeometricSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TessellatedGeometricSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedGeometricSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TessellatedGeometricSet

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedGeometricSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTessellatedGeometricSet

# Register RWStepVisual_RWTessellatedGeometricSet in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTessellatedGeometricSet_swigregister(RWStepVisual_RWTessellatedGeometricSet)

class RWStepVisual_RWTessellatedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTessellatedItem_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTessellatedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TessellatedItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TessellatedItem

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTessellatedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTessellatedItem

# Register RWStepVisual_RWTessellatedItem in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTessellatedItem_swigregister(RWStepVisual_RWTessellatedItem)

class RWStepVisual_RWTextLiteral(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTextLiteral_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTextLiteral(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TextLiteral

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextLiteral_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TextLiteral
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextLiteral_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TextLiteral

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextLiteral_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTextLiteral

# Register RWStepVisual_RWTextLiteral in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTextLiteral_swigregister(RWStepVisual_RWTextLiteral)

class RWStepVisual_RWTextStyle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTextStyle_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTextStyle(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TextStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyle_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TextStyle
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyle_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TextStyle

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyle_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTextStyle

# Register RWStepVisual_RWTextStyle in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTextStyle_swigregister(RWStepVisual_RWTextStyle)

class RWStepVisual_RWTextStyleForDefinedFont(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTextStyleForDefinedFont_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTextStyleForDefinedFont(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TextStyleForDefinedFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyleForDefinedFont_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TextStyleForDefinedFont
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyleForDefinedFont_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TextStyleForDefinedFont

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyleForDefinedFont_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTextStyleForDefinedFont

# Register RWStepVisual_RWTextStyleForDefinedFont in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTextStyleForDefinedFont_swigregister(RWStepVisual_RWTextStyleForDefinedFont)

class RWStepVisual_RWTextStyleWithBoxCharacteristics(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWTextStyleWithBoxCharacteristics_swiginit(self, _RWStepVisual.new_RWStepVisual_RWTextStyleWithBoxCharacteristics(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_TextStyleWithBoxCharacteristics

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyleWithBoxCharacteristics_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_TextStyleWithBoxCharacteristics
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyleWithBoxCharacteristics_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_TextStyleWithBoxCharacteristics

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWTextStyleWithBoxCharacteristics_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWTextStyleWithBoxCharacteristics

# Register RWStepVisual_RWTextStyleWithBoxCharacteristics in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWTextStyleWithBoxCharacteristics_swigregister(RWStepVisual_RWTextStyleWithBoxCharacteristics)

class RWStepVisual_RWViewVolume(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepVisual.RWStepVisual_RWViewVolume_swiginit(self, _RWStepVisual.new_RWStepVisual_RWViewVolume(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepVisual_ViewVolume

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWViewVolume_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepVisual_ViewVolume
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWViewVolume_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepVisual_ViewVolume

        Returns
        -------
        None

        """
        return _RWStepVisual.RWStepVisual_RWViewVolume_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepVisual.delete_RWStepVisual_RWViewVolume

# Register RWStepVisual_RWViewVolume in _RWStepVisual:
_RWStepVisual.RWStepVisual_RWViewVolume_swigregister(RWStepVisual_RWViewVolume)





